==> jc-1.4.0.tar.gz: gnu/java/awt/peer/gtk/GtkScrollbarPeer.h <==
// public class gnu.java.awt.peer.gtk.GtkScrollbarPeer

// class file dependencies
// @dep_class b42ad28212d7bec4 gnu_java_awt_peer_gtk_GtkComponentPeer
// @dep_class d6f9e33c09f7be67 gnu_java_awt_peer_gtk_GtkGenericPeer
// @dep_class fad27b5293ec12e0 gnu_java_awt_peer_gtk_GtkScrollbarPeer
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_awt_peer_gtk_GtkComponentPeer

#include "gnu/java/awt/peer/gtk/GtkComponentPeer.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkScrollbarPeer_H_
#define _JC_gnu_java_awt_peer_gtk_GtkScrollbarPeer_H_

// Forward structure declarations
struct _jc_java_awt_Scrollbar$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$refs	_jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object	_jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$vmethods	_jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$vtable	_jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$vtype	_jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$method$_init$f7a2d2908cec4e5e(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object *, struct _jc_java_awt_Scrollbar$object *);

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$method$connectSignals$b8c8b73de4affb0b(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object *);
extern void _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$method$create$0884e1a8654abdda(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object *);
extern void _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$method$create$0f6cbc7d14b3f466(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object *, jint, jint, jint, jint, jint, jint, jint);
extern void _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$method$postAdjustmentEvent$d775bed7426b03e6(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object *, jint, jint);
extern void _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$method$setLineIncrement$9ded6e0f3cf960a5(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object *, jint);
extern void _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$method$setPageIncrement$23a787af7030cd16(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object *, jint);
extern void _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$method$setValues$89782c28e7b75e50(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object *, jint, jint, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$method_info$connectSignals$b8c8b73de4affb0b;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$method_info$create$0884e1a8654abdda;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$method_info$create$0f6cbc7d14b3f466;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$method_info$postAdjustmentEvent$d775bed7426b03e6;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$method_info$setLineIncrement$9ded6e0f3cf960a5;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$method_info$setPageIncrement$23a787af7030cd16;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$method_info$setValues$89782c28e7b75e50;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$vmethods {
	void	(*connectSignals$b8c8b73de4affb0b)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object *);
	void	(*create$0884e1a8654abdda)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object *);
	void	(*create$0f6cbc7d14b3f466)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object *, jint, jint, jint, jint, jint, jint, jint);
	void	(*postAdjustmentEvent$d775bed7426b03e6)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object *, jint, jint);
	void	(*setLineIncrement$9ded6e0f3cf960a5)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object *, jint);
	void	(*setPageIncrement$23a787af7030cd16)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object *, jint);
	void	(*setValues$89782c28e7b75e50)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object *, jint, jint, jint, jint);
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vmethods	gnu_java_awt_peer_gtk_GtkGenericPeer;
	_jc_gnu_java_awt_peer_gtk_GtkComponentPeer$vmethods	gnu_java_awt_peer_gtk_GtkComponentPeer;
	_jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$vmethods	gnu_java_awt_peer_gtk_GtkScrollbarPeer;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$refs {
    _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$sub_refs	gnu_java_awt_peer_gtk_GtkScrollbarPeer;
    _jc_gnu_java_awt_peer_gtk_GtkComponentPeer$sub_refs	gnu_java_awt_peer_gtk_GtkComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_refs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_gnu_java_awt_peer_gtk_GtkComponentPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkScrollbarPeer;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object {
	_jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$vtype _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkScrollbarPeer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkScrollbarPeer_H_ */

==> jc-1.4.5.tar.gz: gnu/java/awt/peer/gtk/GtkScrollbarPeer.h <==
// public class gnu.java.awt.peer.gtk.GtkScrollbarPeer

// class file dependencies
// @dep_class b42ad28212d7bec4 gnu_java_awt_peer_gtk_GtkComponentPeer
// @dep_class d6f9e33c09f7be67 gnu_java_awt_peer_gtk_GtkGenericPeer
// @dep_class fad27b5293ec12e0 gnu_java_awt_peer_gtk_GtkScrollbarPeer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_awt_peer_gtk_GtkComponentPeer

#include "gnu/java/awt/peer/gtk/GtkComponentPeer.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkScrollbarPeer_H_
#define _JC_gnu_java_awt_peer_gtk_GtkScrollbarPeer_H_

// Forward structure declarations
struct _jc_java_awt_Scrollbar$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$refs	_jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object	_jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$vmethods	_jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$vtable	_jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$vtype	_jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$method$_init$f7a2d2908cec4e5e(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object *, struct _jc_java_awt_Scrollbar$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$method$connectSignals$b8c8b73de4affb0b(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$method$create$0884e1a8654abdda(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$method$create$0f6cbc7d14b3f466(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object *, jint, jint, jint, jint, jint, jint, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$method$postAdjustmentEvent$d775bed7426b03e6(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$method$setLineIncrement$9ded6e0f3cf960a5(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object *, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$method$setPageIncrement$23a787af7030cd16(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object *, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$method$setValues$89782c28e7b75e50(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$method_info$connectSignals$b8c8b73de4affb0b;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$method_info$create$0884e1a8654abdda;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$method_info$create$0f6cbc7d14b3f466;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$method_info$postAdjustmentEvent$d775bed7426b03e6;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$method_info$setLineIncrement$9ded6e0f3cf960a5;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$method_info$setPageIncrement$23a787af7030cd16;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$method_info$setValues$89782c28e7b75e50;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$vmethods {
	void	(*connectSignals$b8c8b73de4affb0b)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object *) _JC_JCNI_ATTR;
	void	(*create$0884e1a8654abdda)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object *) _JC_JCNI_ATTR;
	void	(*create$0f6cbc7d14b3f466)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object *, jint, jint, jint, jint, jint, jint, jint) _JC_JCNI_ATTR;
	void	(*postAdjustmentEvent$d775bed7426b03e6)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object *, jint, jint) _JC_JCNI_ATTR;
	void	(*setLineIncrement$9ded6e0f3cf960a5)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object *, jint) _JC_JCNI_ATTR;
	void	(*setPageIncrement$23a787af7030cd16)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object *, jint) _JC_JCNI_ATTR;
	void	(*setValues$89782c28e7b75e50)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vmethods	gnu_java_awt_peer_gtk_GtkGenericPeer;
	_jc_gnu_java_awt_peer_gtk_GtkComponentPeer$vmethods	gnu_java_awt_peer_gtk_GtkComponentPeer;
	_jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$vmethods	gnu_java_awt_peer_gtk_GtkScrollbarPeer;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$refs {
    _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$sub_refs	gnu_java_awt_peer_gtk_GtkScrollbarPeer;
    _jc_gnu_java_awt_peer_gtk_GtkComponentPeer$sub_refs	gnu_java_awt_peer_gtk_GtkComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_refs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_gnu_java_awt_peer_gtk_GtkComponentPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkScrollbarPeer;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$object {
	_jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$vtype _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkScrollbarPeer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkScrollbarPeer$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkScrollbarPeer_H_ */
